@@ -6,7 +6,7 @@ from ..models.user_list_participant import NotifyUserListParticipant
 class NotifyUserListParticipantInline(admin.TabularInline):
     model = NotifyUserListParticipant
     raw_id_fields = ('user', )
-    fields = ('user', 'email')
+    fields = ('user', 'email', 'phone', 'viber_chat_id')
 
 
 @admin.register(NotifyUserList)
@@ -17,3 +17,4 @@ class NotifyUserListAdmin(admin.ModelAdmin):
     ]
     readonly_fields = ('created_at',)
     search_fields = ('title',)
+    filter_horizontal = ('user_groups',)
