@@ -9,6 +9,12 @@ SMS_API_ID = 1234567890
 SMS_LOGIN = ''
 SMS_PASSWORD = ''
 SMS_FROM = ''
+# CALL
+CALL_URL_TYPE = 0
+CALL_API_ID = 1234567890
+CALL_LOGIN = ''
+CALL_PASSWORD = ''
+CALL_FROM = ''
 # TELEGRAM
 TELEGRAM_API_KEY = '000000000:AAAAAAAAAA-AAAAAAAA-_AAAAAAAAAAAAAA'
 TELEGRAM_BOT_NAME = 'MySuperBot'
